@@ -9,8 +9,12 @@ class RssForm(forms.ModelForm):
     """
         for to handle Rss service
     """
-    my_form_is = forms.CharField(widget=forms.HiddenInput(), initial='rss')
 
     class Meta:
         model = Rss
-        fields = ('name', 'url', 'my_form_is')
+        fields = ('name', 'url', )
+
+
+class RssProviderForm(RssForm):
+    pass
+
